import {Injectable} from '@angular/core';
import {HttpClient} from '@angular/common/http';
import {environment} from '../../environments/environment';
import {PersonModel} from '../models';

@Injectable()
export class PersonService {
  private static internalId = 0;

  constructor(private httpClient: HttpClient) {

  }

  private static responseToPerson(data: any): PersonModel {
    const person = new PersonModel();
    person.id = this.internalId++;
    person.firstname = data.name.first;
    person.lastname = data.name.last;
    person.email = data.email;
    person.image = data.picture.large;

    return person;
  }

  public async getPersons(length: number = 20, seed: string = 'seed'): Promise<PersonModel[]> {
    PersonService.internalId = 0;

    const options = {
      params: {
        results: length.toString(),
        seed: seed
      }
    };

    const result = await this.httpClient.get<{ results: [] }>(environment.api.persons, options).toPromise();
    return result.results.map(element => PersonService.responseToPerson(element));
  }

  public async getPerson(id: number): Promise<PersonModel> {
    const persons = await this.getPersons();

    return persons.find(person => person.id === id);
  }
}
